import { select, 
        json,
        tsv,
        geoNaturalEarth2,
        geoPath,
        zoom,
        event,
        scaleTime,
        scaleLinear,
        max,
        range,
        stack,
        axisBottom,
        axisLeft,
        area,
        curveBasis,
        areaLabel
       } 
from 'd3';


const svg = select('.corona')
              .attr('height',900)
              .attr('width',1000);

const width = 900
const height = 800
const margin = {top:20,bottom:20,left:90,right:20};

const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.right - margin.left;

Promise.all([
  json('covid.json')
])
  .then((data_)=>{
  
   data_ = data_[0]
   const y = data_[0].map(d=> d.Cases)
   
   const yscale = scaleLinear().domain([max(y),0]).range([0,innerHeight]);
  
 
  
   console.log(yscale.domain())
   const xvalue = d => d.Date;

   const date = data_[0].map(d=>new Date(d.Date) );
    
   const xscale = scaleTime().domain([date[0],date[date.length-1]]).range([0,innerWidth]);
  
   let processed = [];

   range(data_[0].length).forEach( d =>{
       let temp = {};
       temp.confirmed = data_[0][d].Cases;  
       processed.push(temp);
   } );
  
  range(data_[1].length).forEach( d =>{
       let temp = {};
       processed[d].recovered = data_[1][d].Cases;     
   } );
  
  range(data_[2].length).forEach( d =>{
       let temp = {};
       processed[d].deaths = data_[2][d].Cases;     
   } );
  
   range(data_[2].length).forEach( d =>{
       let temp = {};
       processed[d].Date = new Date(data_[2][d].Date);     
   } );

  

   const stacked = stack()
                     .order(d3.stackOrderAscending)
   									.keys(['confirmed','recovered','deaths'])(processed);
  
   const ySqscale = d3.scaleLinear()
    .range([innerHeight, 0])
    .domain([
      d3.min(stacked, series => d3.min(series, d => d[0])),
      d3.max(stacked, series => d3.max(series, d => d[1]))
    ])

   console.log(stacked);
  
   const area_ = area()
    .x(d => xscale(xvalue(d.data)))
    .y0(d => ySqscale(d[0]))
    .y1(d => ySqscale(d[1]))
    .curve(curveBasis);
   
   svg.append('g')
      .attr('transform',`translate(${67},${innerHeight})`)
      .call(axisBottom(xscale))
  
   svg.append('g')
      .attr('transform',`translate(${67},${0})`)
      .call(axisLeft(yscale))
       ;
  
   const selection = svg.append('g');
   
   const areas =  selection.selectAll('.area').data(stacked);
   
   const areasEnter = areas.enter().append('path')
                                   .attr('class', 'area')
                                   .attr('transform',`translate(${67},${0})`);
  
   const colorScale =  d3.scaleOrdinal(d3.schemeDark2);
  
   areasEnter.merge(areas)
             .attr('d',area_)
             .attr('fill',d => colorScale(d.key))
  
   areas.select('title')
    .merge(areasEnter.append('title'))
      .text(d => d.key);
  
  var labels = selection.selectAll('.area-label').data(stacked)
     
  labels
    .enter().append('text')
      .attr('class', 'area-label')
    .merge(labels)
      .text(d => d.key)
      .attr('transform', areaLabel(area_).interpolateResolution(1000));
  
  var months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
  
  svg.append('text').attr('class','heading')
      .text(`India Covid cases status from 
${ date[0].getDate()}th ${ months[date[0].getMonth()] } to
${ date[date.length-1].getDate()}th ${ months[date[date.length-1].getMonth()] } `)
      .attr('transform',`translate(100,40)`)
  
  console.log(date[date.length-1].getDay());
  
});